Released: pip 7.0 and virtualenv 13.0
Hey, I'm happy to say that I've just cut the releases of pip 7.0 and virtualenv 13.0 and I have uploaded them to PyPI. For the full list of changes go visit the respective changelogs, however the biggest change here is that in pip 7.0 when pip finds and downloads a sdist, instead of installing that sdist directly it will instead build a wheel of that and cache it locally. From then on out it will use that cached wheel to install instead of downloading and building the sdist each time. This can have a profound impact upon installation speed. For instance, taking a look at the popular lxml library: # Without a locally cached wheel $ time pip install lxml ... pip install lxml 36.00s user 1.40s system 98% cpu 38.117 total # The next time, with a primed cache. $ time pip install lxml ... pip install lxml 0.61s user 0.10s system 94% cpu 0.750 total Some important notes about this new feature: * If the wheel project is not installed, then this feature will be disabled, however get-pip.py and virtualenv both will now install wheel by default. * If attempting to actually *build* the wheel fails for any reason, it will fall back to the older method of simply installing the sdist directly. * If a project cannot be installed correctly from a wheel, but it can successfully build a wheel, you can disable using wheels for that project by adding the flag --no-binary project1,project2,project3 to tell pip not to use binaries for those projects. You can use the :all: psuedo identifier to disable all wheels. I'm pretty excited about this release, caching built wheels is going to result in a tremendous speedup for a lot of common cases. As with any big change there is a pretty good change that this will cause breakages for some percentage of projects as well as have bugs within the system itself. As always, if you find a bug please feel free to open an issue up on the pip issue tracker at https://github.com/pypa/pip/issues. --- Donald Stufft PGP: 7C6B 7C5D 5E2B 6356 A926 F04F 6E3C BCE9 3372 DCFA
Thanks! Someone (or I) could also update these: * https://github.com/conda/conda-recipes/blob/master/pip/meta.yaml * https://github.com/conda/conda-recipes/blob/master/virtualenv/meta.yaml * https://github.com/conda/conda-recipes/blob/master/virtualenvwrapper/meta.ya... On May 21, 2015 11:21 PM, "Donald Stufft" <donald@stufft.io> wrote:
Hey,
I'm happy to say that I've just cut the releases of pip 7.0 and virtualenv 13.0 and I have uploaded them to PyPI. For the full list of changes go visit the respective changelogs, however the biggest change here is that in pip 7.0 when pip finds and downloads a sdist, instead of installing that sdist directly it will instead build a wheel of that and cache it locally. From then on out it will use that cached wheel to install instead of downloading and building the sdist each time. This can have a profound impact upon installation speed.
For instance, taking a look at the popular lxml library:
# Without a locally cached wheel $ time pip install lxml ... pip install lxml 36.00s user 1.40s system 98% cpu 38.117 total
# The next time, with a primed cache. $ time pip install lxml ... pip install lxml 0.61s user 0.10s system 94% cpu 0.750 total
Some important notes about this new feature:
* If the wheel project is not installed, then this feature will be disabled, however get-pip.py and virtualenv both will now install wheel by default.
* If attempting to actually *build* the wheel fails for any reason, it will fall back to the older method of simply installing the sdist directly.
* If a project cannot be installed correctly from a wheel, but it can successfully build a wheel, you can disable using wheels for that project by adding the flag --no-binary project1,project2,project3 to tell pip not to use binaries for those projects. You can use the :all: psuedo identifier to disable all wheels.
I'm pretty excited about this release, caching built wheels is going to result in a tremendous speedup for a lot of common cases. As with any big change there is a pretty good change that this will cause breakages for some percentage of projects as well as have bugs within the system itself. As always, if you find a bug please feel free to open an issue up on the pip issue tracker at https://github.com/pypa/pip/issues.
--- Donald Stufft PGP: 7C6B 7C5D 5E2B 6356 A926 F04F 6E3C BCE9 3372 DCFA
_______________________________________________ Distutils-SIG maillist - Distutils-SIG@python.org https://mail.python.org/mailman/listinfo/distutils-sig
On Fri, May 22, 2015 at 12:34 AM, Wes Turner <wes.turner@gmail.com> wrote:
Thanks!
Someone (or I) could also update these: * https://github.com/conda/conda-recipes/blob/master/pip/meta.yaml * https://github.com/conda/conda-recipes/blob/master/virtualenv/meta.yaml
* https://github.com/conda/conda-recipes/blob/master/virtualenvwrapper/meta.ya...
Here's this start at updating conda-recipes with the latest PyPA + [virtualenvwrapper, peep] packages https://github.com/conda/conda-recipes/compare/master...westurner:pip_7.0.0 * pip 7.0.0 * virtualenv 13.0 * wheel 0.24.0 * virtualenvwrapper 4.5.1 * peep 2.4.1 Blocking: * BUG: pip 7.0.0 errors with """OSError: [Errno 17] File exists: '${CONDAENV}/_build/lib/python2.7/site-packages/pip/_vendor'""" Thanks again!
On May 21, 2015 11:21 PM, "Donald Stufft" <donald@stufft.io> wrote:
Hey,
I'm happy to say that I've just cut the releases of pip 7.0 and virtualenv 13.0 and I have uploaded them to PyPI. For the full list of changes go visit the respective changelogs, however the biggest change here is that in pip 7.0 when pip finds and downloads a sdist, instead of installing that sdist directly it will instead build a wheel of that and cache it locally. From then on out it will use that cached wheel to install instead of downloading and building the sdist each time. This can have a profound impact upon installation speed.
For instance, taking a look at the popular lxml library:
# Without a locally cached wheel $ time pip install lxml ... pip install lxml 36.00s user 1.40s system 98% cpu 38.117 total
# The next time, with a primed cache. $ time pip install lxml ... pip install lxml 0.61s user 0.10s system 94% cpu 0.750 total
Some important notes about this new feature:
* If the wheel project is not installed, then this feature will be disabled, however get-pip.py and virtualenv both will now install wheel by default.
* If attempting to actually *build* the wheel fails for any reason, it will fall back to the older method of simply installing the sdist directly.
* If a project cannot be installed correctly from a wheel, but it can successfully build a wheel, you can disable using wheels for that project by adding the flag --no-binary project1,project2,project3 to tell pip not to use binaries for those projects. You can use the :all: psuedo identifier to disable all wheels.
I'm pretty excited about this release, caching built wheels is going to result in a tremendous speedup for a lot of common cases. As with any big change there is a pretty good change that this will cause breakages for some percentage of projects as well as have bugs within the system itself. As always, if you find a bug please feel free to open an issue up on the pip issue tracker at https://github.com/pypa/pip/issues.
--- Donald Stufft PGP: 7C6B 7C5D 5E2B 6356 A926 F04F 6E3C BCE9 3372 DCFA
_______________________________________________ Distutils-SIG maillist - Distutils-SIG@python.org https://mail.python.org/mailman/listinfo/distutils-sig
On 22 May 2015 at 05:21, Donald Stufft <donald@stufft.io> wrote:
I'm happy to say that I've just cut the releases of pip 7.0 and virtualenv 13.0 and I have uploaded them to PyPI. For the full list of changes go visit the respective changelogs, however the biggest change here is that in pip 7.0 when pip finds and downloads a sdist, instead of installing that sdist directly it will instead build a wheel of that and cache it locally. From then on out it will use that cached wheel to install instead of downloading and building the sdist each time. This can have a profound impact upon installation speed.
Nice! I've been looking forward to this for ages. Thanks to all who worked on the change - in particular Robert Collins who did the bulk of the implementation. Paul
On 22 May 2015 14:21, "Donald Stufft" <donald@stufft.io> wrote:
Hey,
I'm happy to say that I've just cut the releases of pip 7.0 and
and I have uploaded them to PyPI. For the full list of changes go visit
virtualenv 13.0 the
respective changelogs, however the biggest change here is that in pip 7.0 when pip finds and downloads a sdist, instead of installing that sdist directly it will instead build a wheel of that and cache it locally. From then on out it will use that cached wheel to install instead of downloading and building the sdist each time. This can have a profound impact upon installation speed.
Huzzah! Great work folks :) Cheers, Nick.
Congrats on the release, wheel caching for sdist is a great new feature! -- Olivier
-----BEGIN PGP SIGNED MESSAGE----- Hash: SHA1 On 05/22/2015 12:21 AM, Donald Stufft wrote:
I'm happy to say that I've just cut the releases of pip 7.0 and virtualenv 13.0 and I have uploaded them to PyPI. For the full list of changes go visit the respective changelogs, however the biggest change here is that in pip 7.0 when pip finds and downloads a sdist, instead of installing that sdist directly it will instead build a wheel of that and cache it locally. From then on out it will use that cached wheel to install instead of downloading and building the sdist each time. This can have a profound impact upon installation speed.
Nice! I was hoping that this release would make ;tox -e jython` finally work: it's closer, but fails now due to the fact that the '.tox/jython/bin/pip' script isn't set to executable. I don't know whether that is an issue with the pip bundled in Jython 2.7.0, or some other weirdness. Tres. - -- =================================================================== Tres Seaver +1 540-429-0999 tseaver@palladion.com Palladion Software "Excellence by Design" http://palladion.com -----BEGIN PGP SIGNATURE----- Version: GnuPG v1.4.11 (GNU/Linux) iQIcBAEBAgAGBQJVXxoyAAoJEPKpaDSJE9HYhjUP/RADiv/qM2xRg8UednYfxLub 1AUQk+GRYR4B1zbcNu/f8tcXeKePde7QaQ3si1EE123CBQxk85xqMH/2oYFqwCsw Dxb7QuQdHhhuImxpM4SIVJmb0Tm8YqYIkDNH0NAuRVWkgaWQDfQgHVYlNQWxog/e 8hEnEWs3HjF+9+7GcTL7ny+l6CAmlh32zJaPQi0j+hzYbS54iShYzcWzlkSltFmU N4LLIlel9SWyX0WclpeuP4hhygpPlkqAoMPmh73m1/74jk0My8qXC2UY5KwU/Iar ugK3KOTAohpeTvbgK9wdIzOuqYoX6k0IgAHFejcbXWYoDNFUvS7HAqCoyCHA7JJJ 9SZsWRf8rCfaGEzWrAR3PVOMGmpLO4DuQBZZ3sypIRC2stTOtXzQc5gg0CjvHZjH DVmjXF0/WBcngAnUdkDjIwZTxvQuR0NJEV7H6ODMNwO+UaBGTCojih1JDVG+GYW6 2uXUSAWBlX50zBph6U2GbouAwUbtzTlb8LWFdj/GIQ2UvNwoF4f84EougriXFAnl ODkPxjHt0l9N8WIGfq2v32aHl+VsNgRMptZMV38fGxCSOGM6Eo/eUQgY2Qfcx8g7 wOUHcQRyTAs8AT0Dy++eOZNrdndvQFiYKUMIUzJJaeHuEbGaeKruiOva7/+65GNr N90Y/+cw/feYl/eIOeP4 =Me4+ -----END PGP SIGNATURE-----
On 05/22/2015 12:21 AM, Donald Stufft wrote:
From then on out it will use that cached wheel to install instead of downloading and building the sdist each time.
Soooo great! Thanks to the pip team for their diligence! *Randy Syring* Husband | Father | Redeemed Sinner /"For what does it profit a man to gain the whole world and forfeit his soul?" (Mark 8:36 ESV)/
participants (7)
-
Donald Stufft -
Nick Coghlan -
Olivier Grisel -
Paul Moore -
Randy Syring -
Tres Seaver -
Wes Turner